Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(525)

Unified Diff: recipes/skia.py

Issue 746363003: Add fetch recipe for the Skia repository. (Closed) Base URL: https://chromium.googlesource.com/chromium/tools/depot_tools.git@master
Patch Set: Created 6 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: recipes/skia.py
diff --git a/recipes/infra.py b/recipes/skia.py
similarity index 52%
copy from recipes/infra.py
copy to recipes/skia.py
index 3c65b4420f78aaef05421dfd187a64fbe50e7863..171157c43ffaac2108a107db07e59981737d839e 100644
--- a/recipes/infra.py
+++ b/recipes/skia.py
@@ -9,25 +9,19 @@ import recipe_util # pylint: disable=F0401
# This class doesn't need an __init__ method, so we disable the warning
# pylint: disable=W0232
-class Infra(recipe_util.Recipe):
- """Basic Recipe class for the Infrastructure repositories."""
+class Skia(recipe_util.Recipe):
+ """Basic Recipe class for the Skia repository."""
@staticmethod
def fetch_spec(_props):
- solution = lambda name, path_infix = None: {
- 'name' : name,
- 'url' : 'https://chromium.googlesource.com/infra/%s%s.git' % (
- path_infix + '/' if path_infix else '', name
- ),
- 'deps_file': '.DEPS.git',
+ solution = {
+ 'name' : 'skia',
+ 'url' : 'https://skia.googlesource.com/skia.git',
+ 'deps_file': 'DEPS',
'managed' : False,
}
spec = {
- 'solutions': [
- solution('infra'),
- solution('expect_tests', 'testing'),
- solution('testing_support', 'testing'),
- ],
+ 'solutions': [solution]
}
return {
'type': 'gclient_git',
@@ -36,11 +30,11 @@ class Infra(recipe_util.Recipe):
@staticmethod
def expected_root(_props):
- return 'infra'
+ return 'skia'
def main(argv=None):
- return Infra().handle_args(argv)
+ return Skia().handle_args(argv)
if __name__ == '__main__':
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698